# Unofficial python stubs for SideFX Hourini

These stubs are designed to be used with a type checker like `mypy` to provide static type checking of python code, as well as to provide analysis and completion in IDEs like PyCharm and VSCode (with Pylance).

## Installing

```commandline
pip install types-houdini
```

The version of the package corresponds to the version of Houdini that it is generated from,
plus a version suffix for the revision of the stubs
